@@ -73,6 +73,8 @@ Filter::Filter(const std::string& tag, pw::Manager* pipe_manager, PipelineType p
 }
 
 Filter::~Filter() {
+  stop_worker();
+
   if (connected_to_pw) {
     disconnect_from_pw();
   }
@@ -111,10 +113,14 @@ void Filter::setup() {
     return;
   }
 
-  ready = false;
-
   lv2_wrapper->set_n_samples(n_samples);
 
+  if (lv2_wrapper->has_instance() && rate == lv2_wrapper->get_rate()) {
+    return;
+  }
+
+  ready = false;
+
   // NOLINTBEGIN(clang-analyzer-cplusplus.NewDeleteLeaks)
   QMetaObject::invokeMethod(
       baseWorker,
