@@ -46,6 +46,8 @@ class MultibandCompressor : public PluginBase {
 
   void reset() override;
 
+  void clear_data() override;
+
   void setup() override;
 
   void process(std::span<float>& left_in,
@@ -78,6 +80,8 @@ class MultibandCompressor : public PluginBase {
  private:
   uint latency_n_frames = 0U;
 
+  bool ready = false;
+
   static constexpr uint n_bands = tags::multiband_compressor::n_bands;
 
   db::MultibandCompressor* settings = nullptr;
